# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/activities/activities.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/activities/activities.proto',
  package='yamcs.protobuf.activities',
  syntax='proto2',
  serialized_options=b'\n\035org.yamcs.protobuf.activitiesB\017ActivitiesProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/activities/activities.proto\x12\x19yamcs.protobuf.activities\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"^\n\x16\x41\x63tivityDefinitionInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12%\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\"\xb9\x02\n\x0c\x41\x63tivityInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03seq\x18\x03 \x01(\r\x12\x39\n\x06status\x18\x04 \x01(\x0e\x32).yamcs.protobuf.activities.ActivityStatus\x12\x11\n\tstartedBy\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12%\n\x04\x61rgs\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x64\x65tail\x18\x08 \x01(\t\x12(\n\x04stop\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tstoppedBy\x18\n \x01(\t\x12\x15\n\rfailureReason\x18\x0b \x01(\t\"T\n\x0c\x45xecutorInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\"\x98\x01\n\x0f\x41\x63tivityLogInfo\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06source\x18\x02 \x01(\t\x12:\n\x05level\x18\x03 \x01(\x0e\x32+.yamcs.protobuf.activities.ActivityLogLevel\x12\x0f\n\x07message\x18\x04 \x01(\t*H\n\x0e\x41\x63tivityStatus\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x0e\n\nSUCCESSFUL\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04*4\n\x10\x41\x63tivityLogLevel\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x42\x32\n\x1dorg.yamcs.protobuf.activitiesB\x0f\x41\x63tivitiesProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ACTIVITYSTATUS = _descriptor.EnumDescriptor(
  name='ActivityStatus',
  full_name='yamcs.protobuf.activities.ActivityStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESSFUL', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=789,
  serialized_end=861,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITYSTATUS)

ActivityStatus = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYSTATUS)
_ACTIVITYLOGLEVEL = _descriptor.EnumDescriptor(
  name='ActivityLogLevel',
  full_name='yamcs.protobuf.activities.ActivityLogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INFO', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=863,
  serialized_end=915,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITYLOGLEVEL)

ActivityLogLevel = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYLOGLEVEL)
RUNNING = 1
CANCELLED = 2
SUCCESSFUL = 3
FAILED = 4
INFO = 1
WARNING = 2
ERROR = 3



_ACTIVITYDEFINITIONINFO = _descriptor.Descriptor(
  name='ActivityDefinitionInfo',
  full_name='yamcs.protobuf.activities.ActivityDefinitionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ActivityDefinitionInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='yamcs.protobuf.activities.ActivityDefinitionInfo.args', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.activities.ActivityDefinitionInfo.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=230,
)


_ACTIVITYINFO = _descriptor.Descriptor(
  name='ActivityInfo',
  full_name='yamcs.protobuf.activities.ActivityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.activities.ActivityInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.activities.ActivityInfo.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.protobuf.activities.ActivityInfo.seq', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.activities.ActivityInfo.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startedBy', full_name='yamcs.protobuf.activities.ActivityInfo.startedBy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ActivityInfo.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='yamcs.protobuf.activities.ActivityInfo.args', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='yamcs.protobuf.activities.ActivityInfo.detail', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.activities.ActivityInfo.stop', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stoppedBy', full_name='yamcs.protobuf.activities.ActivityInfo.stoppedBy', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.activities.ActivityInfo.failureReason', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=546,
)


_EXECUTORINFO = _descriptor.Descriptor(
  name='ExecutorInfo',
  full_name='yamcs.protobuf.activities.ExecutorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ExecutorInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayName', full_name='yamcs.protobuf.activities.ExecutorInfo.displayName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.activities.ExecutorInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icon', full_name='yamcs.protobuf.activities.ExecutorInfo.icon', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=632,
)


_ACTIVITYLOGINFO = _descriptor.Descriptor(
  name='ActivityLogInfo',
  full_name='yamcs.protobuf.activities.ActivityLogInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.activities.ActivityLogInfo.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.activities.ActivityLogInfo.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.activities.ActivityLogInfo.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.activities.ActivityLogInfo.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=787,
)

_ACTIVITYDEFINITIONINFO.fields_by_name['args'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ACTIVITYINFO.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYINFO.fields_by_name['status'].enum_type = _ACTIVITYSTATUS
_ACTIVITYINFO.fields_by_name['args'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ACTIVITYINFO.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYLOGINFO.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYLOGINFO.fields_by_name['level'].enum_type = _ACTIVITYLOGLEVEL
DESCRIPTOR.message_types_by_name['ActivityDefinitionInfo'] = _ACTIVITYDEFINITIONINFO
DESCRIPTOR.message_types_by_name['ActivityInfo'] = _ACTIVITYINFO
DESCRIPTOR.message_types_by_name['ExecutorInfo'] = _EXECUTORINFO
DESCRIPTOR.message_types_by_name['ActivityLogInfo'] = _ACTIVITYLOGINFO
DESCRIPTOR.enum_types_by_name['ActivityStatus'] = _ACTIVITYSTATUS
DESCRIPTOR.enum_types_by_name['ActivityLogLevel'] = _ACTIVITYLOGLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivityDefinitionInfo = _reflection.GeneratedProtocolMessageType('ActivityDefinitionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYDEFINITIONINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ActivityDefinitionInfo)
  })
_sym_db.RegisterMessage(ActivityDefinitionInfo)

ActivityInfo = _reflection.GeneratedProtocolMessageType('ActivityInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ActivityInfo)
  })
_sym_db.RegisterMessage(ActivityInfo)

ExecutorInfo = _reflection.GeneratedProtocolMessageType('ExecutorInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTORINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ExecutorInfo)
  })
_sym_db.RegisterMessage(ExecutorInfo)

ActivityLogInfo = _reflection.GeneratedProtocolMessageType('ActivityLogInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLOGINFO,
  '__module__' : 'yamcs.protobuf.activities.activities_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ActivityLogInfo)
  })
_sym_db.RegisterMessage(ActivityLogInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import base64
from datetime import datetime, timedelta, timezone
from typing import Callable, Optional

import requests
from requests.auth import HTTPBasicAuth
from yamcs.core.exceptions import Unauthorized, YamcsError
from yamcs.core.helpers import do_post


def _convert_user_credentials(
    session: requests.Session,
    token_url: str,
    username: Optional[str] = None,
    password: Optional[str] = None,
    refresh_token: Optional[str] = None,
) -> "Credentials":
    """
    Converts username/password credentials to token credentials by
    using Yamcs as the authentication server.
    """
    if username and password:
        data = {"grant_type": "password", "username": username, "password": password}
    elif refresh_token:
        data = {"grant_type": "refresh_token", "refresh_token": refresh_token}
    else:
        raise NotImplementedError()

    response = do_post(session, token_url, data=data)
    if response.status_code == 401:
        raise Unauthorized("401 Client Error: Unauthorized")
    elif response.status_code == 200:
        d = response.json()
        expiry = datetime.now(tz=timezone.utc) + timedelta(seconds=d["expires_in"])
        return Credentials(
            access_token=d["access_token"],
            refresh_token=d["refresh_token"],
            expiry=expiry,
        )
    else:
        raise YamcsError(f"{response.status_code} Server Error")


def _convert_service_account_credentials(
    session: requests.Session,
    token_url: str,
    client_id: str,
    client_secret: str,
    become: str,
) -> "Credentials":
    """
    Converts service account credentials to impersonated token credentials.
    """
    data = {"grant_type": "client_credentials", "become": become}

    response = do_post(
        session,
        token_url,
        data=data,
        auth=HTTPBasicAuth(client_id, client_secret),
    )
    if response.status_code == 401:
        raise Unauthorized("401 Client Error: Unauthorized")
    elif response.status_code == 200:
        d = response.json()
        expiry = datetime.now(tz=timezone.utc) + timedelta(seconds=d["expires_in"])
        return Credentials(
            access_token=d["access_token"],
            client_id=client_id,
            client_secret=client_secret,
            become=become,
            expiry=expiry,
        )
    else:
        raise YamcsError(f"{response.status_code} Server Error")


class Credentials:
    """
    Data holder for different types of credentials. Currently this includes:

    * Username/password credentials (fields ``username`` and ``password``)
    * Bearer tokens (fields ``access_token`` and optionally ``refresh_token``)
    """

    def __init__(
        self,
        username: Optional[str] = None,
        password: Optional[str] = None,
        access_token: Optional[str] = None,
        refresh_token: Optional[str] = None,
        expiry: Optional[datetime] = None,
        client_id: Optional[str] = None,
        client_secret: Optional[str] = None,
        become: Optional[str] = None,
    ):
        self.username = username
        """Username (only needed when using username/password credentials)."""

        self.password = password
        """Clear-text password (consider TLS!)."""

        self.access_token = access_token
        """Short-lived bearer token."""

        self.refresh_token = refresh_token
        """Refresh token used to request a new access token."""

        self.expiry = expiry
        """When this token expires."""

        self.client_id = client_id
        """The client ID. Currently used only by service accounts."""

        self.client_secret = client_secret
        """The client secret. Currently used only by service accounts."""

        self.become = become
        """
        Name of the user to impersonate. Only service accounts with
        impersonation authority can use this feature.
        """

        self._on_token_update = None

    def login(
        self,
        session: requests.Session,
        auth_url: str,
        on_token_update: Optional[Callable[["Credentials"], None]],
    ) -> "Credentials":
        self._on_token_update = on_token_update
        token_url = auth_url + "/token"
        if self.username:  # Convert u/p to bearer
            creds = _convert_user_credentials(
                session, token_url, username=self.username, password=self.password
            )
        elif self.become:  # Impersonate from service account
            creds = _convert_service_account_credentials(
                session,
                token_url,
                client_id=str(self.client_id),
                client_secret=str(self.client_secret),
                become=self.become,
            )
        else:
            creds = self

        if on_token_update:
            on_token_update(creds)
        return creds

    def is_expired(self) -> bool:
        if self.expiry is not None:
            return self.expiry and datetime.now(tz=timezone.utc) >= self.expiry
        else:
            return False

    def refresh(self, session: requests.Session, auth_url: str):
        if self.become:
            new_creds = _convert_service_account_credentials(
                session,
                auth_url + "/token",
                client_id=str(self.client_id),
                client_secret=str(self.client_secret),
                become=self.become,
            )
        elif self.refresh_token:
            new_creds = _convert_user_credentials(
                session, auth_url + "/token", refresh_token=self.refresh_token
            )
        else:
            raise YamcsError("Missing refresh token")

        self.access_token = new_creds.access_token
        self.refresh_token = new_creds.refresh_token
        self.expiry = new_creds.expiry
        if self._on_token_update:
            self._on_token_update(self)

    def before_request(self, session: requests.Session, auth_url: str):
        if self.is_expired():
            self.refresh(session, auth_url)

        if self.access_token:
            session.headers.update({"Authorization": "Bearer " + self.access_token})


class BasicAuthCredentials(Credentials):
    """
    Data holder for Basic Auth credentials. This includes a username and a password
    which are passed in the HTTP Authorization header on each request.
    """

    def __init__(self, username: str, password: str):
        super().__init__(username=username, password=password)

    def is_expired(self) -> bool:
        return False

    def refresh(self):
        pass

    def login(self, *args, **kwargs):
        return self

    def before_request(self, session: requests.Session, auth_url: str):
        buf = str.encode(f"{self.username}:{self.password}")
        usernamePass = base64.b64encode(buf).decode()
        session.headers.update({"Authorization": "Basic " + usernamePass})


class APIKeyCredentials(Credentials):
    def __init__(self, key: str):
        super().__init__(password=key)

    def is_expired(self) -> bool:
        return False

    def refresh(self):
        pass

    def login(self, *args, **kwargs):
        return self

    def before_request(self, session: requests.Session, auth_url: str):
        session.headers.update({"x-api-key": str(self.password)})



import threading
from concurrent.futures import Future

from yamcs.core.exceptions import TimeoutError, YamcsError
from yamcs.core.subscriptions import WebSocketSubscriptionManager


class WebSocketSubscriptionFuture(Future):
    """
    Future for capturing the asynchronous execution of a WebSocket subscription.
    """

    def __init__(self, manager: WebSocketSubscriptionManager):
        super(WebSocketSubscriptionFuture, self).__init__()
        self.ctx = manager.ctx
        self._manager = manager
        self._manager.add_response_callback(self._on_response_callback)
        self._manager.add_close_callback(self._on_close_callback)

        # Yamcs send either a 'reply' message or an 'exception' message on
        # every websocket subscription. If the ``_response_received`` event
        # is set it means either of these two has arrived, or the connection
        # failed entirely
        self._response_received = threading.Event()
        self._response_reply = None
        self._response_exception = None

        self._result = None
        self._exception = None
        self._callbacks = []

        self._completed = threading.Event()
        self._cancelled = False

    def _on_response_callback(self, manager, reply=None, exception=None):
        self._response_reply = reply
        self._response_exception = exception
        self._response_received.set()

        # Yamcs leaves the socket open because it was designed with
        # multiple parallel subscriptions in mind. We don't use this
        # notion, so close the connection.
        if exception:
            closer = threading.Thread(
                target=self._manager.close, kwargs={"reason": exception},
            )
            closer.daemon = True
            closer.start()

    def _on_close_callback(self, manager, result):
        if result is None:
            self.set_result(True)
        else:
            self.set_exception(result)

            # Make sure no subscriptions get stuck
            # on waiting for an initial reply.
            self._response_received.set()

    def cancel(self):
        """
        Closes the websocket and shutdowns the background thread consuming
        messages.
        """
        self._cancelled = True
        return self._manager.close()

    def cancelled(self):
        return self._cancelled

    def running(self):
        if self.done():
            return False
        return True

    def done(self):
        # Assume that None cannot be a valid result
        return self._exception is not None or self._result is not None

    def reply(self, timeout=None):
        """
        Returns the initial reply. This is emitted before any subscription
        data is emitted. This function raises an exception if the subscription
        attempt failed.
        """
        self._wait_on_signal(self._response_received, timeout)
        if self._response_exception is not None:
            msg = self._response_exception.msg
            raise YamcsError(msg)
        elif self._exception:
            raise self._exception
        return self._response_reply

    def result(self, timeout=None):
        err = self.exception(timeout=timeout)
        if err is None:
            return self._result
        raise err

    def exception(self, timeout=None):
        self._wait_on_signal(self._completed, timeout)

        if self._result is not None:
            return None

        return self._exception

    def _wait_on_signal(self, event, timeout=None):
        if not event.wait(timeout=timeout):
            # Remark that a timeout does *not* mean that the underlying
            # work is canceled.
            raise TimeoutError("Timed out.")

    def add_done_callback(self, fn):
        if self.done():
            fn(self)
        self._callbacks.append(fn)

    def set_result(self, result):
        assert not self.done()

        self._result = result
        self._completed.set()
        for callback in self._callbacks:
            callback(self)

    def set_exception(self, exception):
        assert not self.done()

        self._exception = exception
        self._completed.set()
        for callback in self._callbacks:
            callback(self)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/index_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/index_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\021IndexServiceProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/archive/index_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xc5\x01\n\x1eListCommandHistoryIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x03(\t\"\xbe\x01\n\x15ListEventIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x03(\t\"\xbd\x01\n\x16ListPacketIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x03(\t\"\xc1\x01\n\x19ListParameterIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\r\n\x05group\x18\x07 \x03(\t\"\xb5\x01\n\x1cListCompletenessIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x05 \x01(\t\"]\n\rIndexResponse\x12\x31\n\x05group\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.archive.IndexGroup\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"j\n\nIndexGroup\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x31\n\x05\x65ntry\x18\x02 \x03(\x0b\x32\".yamcs.protobuf.archive.IndexEntry\"[\n\nIndexEntry\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x10\n\x08seqStart\x18\x04 \x01(\x03\x12\x0f\n\x07seqStop\x18\x05 \x01(\x03\"\xa3\x01\n\x18StreamPacketIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05names\x18\x04 \x03(\t\x12\x11\n\tmergeTime\x18\x05 \x01(\r\"\x97\x01\n\x1bStreamParameterIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\x05\"\x95\x01\n\x19StreamCommandIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\x05\"\x93\x01\n\x17StreamEventIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\x05\"\x9a\x01\n\x1eStreamCompletenessIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmergeTime\x18\x04 \x01(\r\"\x81\x01\n\x18RebuildCcsdsIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe8\r\n\nIndexesApi\x12\xa5\x01\n\x17ListCommandHistoryIndex\x12\x36.yamcs.protobuf.archive.ListCommandHistoryIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"+\x8a\x92\x03\'\n%/api/archive/{instance}/command-index\x12\x91\x01\n\x0eListEventIndex\x12-.yamcs.protobuf.archive.ListEventIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\")\x8a\x92\x03%\n#/api/archive/{instance}/event-index\x12\x94\x01\n\x0fListPacketIndex\x12..yamcs.protobuf.archive.ListPacketIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"*\x8a\x92\x03&\n$/api/archive/{instance}/packet-index\x12\x9d\x01\n\x12ListParameterIndex\x12\x31.yamcs.protobuf.archive.ListParameterIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"-\x8a\x92\x03)\n\'/api/archive/{instance}/parameter-index\x12\xa6\x01\n\x15ListCompletenessIndex\x12\x34.yamcs.protobuf.archive.ListCompletenessIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"0\x8a\x92\x03,\n*/api/archive/{instance}/completeness-index\x12\x9a\x01\n\x11StreamPacketIndex\x12\x30.yamcs.protobuf.archive.StreamPacketIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"2\x8a\x92\x03.\x1a)/api/archive/{instance}:streamPacketIndex:\x01*0\x01\x12\xa3\x01\n\x14StreamParameterIndex\x12\x33.yamcs.protobuf.archive.StreamParameterIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"5\x8a\x92\x03\x31\x1a,/api/archive/{instance}:streamParameterIndex:\x01*0\x01\x12\x9d\x01\n\x12StreamCommandIndex\x12\x31.yamcs.protobuf.archive.StreamCommandIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"3\x8a\x92\x03/\x1a*/api/archive/{instance}:streamCommandIndex:\x01*0\x01\x12\x97\x01\n\x10StreamEventIndex\x12/.yamcs.protobuf.archive.StreamEventIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"1\x8a\x92\x03-\x1a(/api/archive/{instance}:streamEventIndex:\x01*0\x01\x12\xac\x01\n\x17StreamCompletenessIndex\x12\x36.yamcs.protobuf.archive.StreamCompletenessIndexRequest\x1a\x1d.yamcs.protobuf.ArchiveRecord\"8\x8a\x92\x03\x34\x1a//api/archive/{instance}:streamCompletenessIndex:\x01*0\x01\x12\x91\x01\n\x11RebuildCcsdsIndex\x12\x30.yamcs.protobuf.archive.RebuildCcsdsIndexRequest\x1a\x16.google.protobuf.Empty\"2\x8a\x92\x03.\x1a)/api/archive/{instance}:rebuildCcsdsIndex:\x01*B)\n\x12org.yamcs.protobufB\x11IndexServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTCOMMANDHISTORYINDEXREQUEST = _descriptor.Descriptor(
  name='ListCommandHistoryIndexRequest',
  full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.name', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=387,
)


_LISTEVENTINDEXREQUEST = _descriptor.Descriptor(
  name='ListEventIndexRequest',
  full_name='yamcs.protobuf.archive.ListEventIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListEventIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListEventIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListEventIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListEventIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListEventIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListEventIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListEventIndexRequest.source', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=580,
)


_LISTPACKETINDEXREQUEST = _descriptor.Descriptor(
  name='ListPacketIndexRequest',
  full_name='yamcs.protobuf.archive.ListPacketIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.name', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=772,
)


_LISTPARAMETERINDEXREQUEST = _descriptor.Descriptor(
  name='ListParameterIndexRequest',
  full_name='yamcs.protobuf.archive.ListParameterIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.group', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=968,
)


_LISTCOMPLETENESSINDEXREQUEST = _descriptor.Descriptor(
  name='ListCompletenessIndexRequest',
  full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.mergeTime', index=1,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.limit', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.start', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.stop', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.next', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1152,
)


_INDEXRESPONSE = _descriptor.Descriptor(
  name='IndexResponse',
  full_name='yamcs.protobuf.archive.IndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.IndexResponse.group', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.IndexResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1247,
)


_INDEXGROUP = _descriptor.Descriptor(
  name='IndexGroup',
  full_name='yamcs.protobuf.archive.IndexGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.archive.IndexGroup.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.archive.IndexGroup.entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1355,
)


_INDEXENTRY = _descriptor.Descriptor(
  name='IndexEntry',
  full_name='yamcs.protobuf.archive.IndexEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.IndexEntry.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.IndexEntry.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.archive.IndexEntry.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqStart', full_name='yamcs.protobuf.archive.IndexEntry.seqStart', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqStop', full_name='yamcs.protobuf.archive.IndexEntry.seqStop', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1357,
  serialized_end=1448,
)


_STREAMPACKETINDEXREQUEST = _descriptor.Descriptor(
  name='StreamPacketIndexRequest',
  full_name='yamcs.protobuf.archive.StreamPacketIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamPacketIndexRequest.mergeTime', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1451,
  serialized_end=1614,
)


_STREAMPARAMETERINDEXREQUEST = _descriptor.Descriptor(
  name='StreamParameterIndexRequest',
  full_name='yamcs.protobuf.archive.StreamParameterIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamParameterIndexRequest.mergeTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1768,
)


_STREAMCOMMANDINDEXREQUEST = _descriptor.Descriptor(
  name='StreamCommandIndexRequest',
  full_name='yamcs.protobuf.archive.StreamCommandIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamCommandIndexRequest.mergeTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1771,
  serialized_end=1920,
)


_STREAMEVENTINDEXREQUEST = _descriptor.Descriptor(
  name='StreamEventIndexRequest',
  full_name='yamcs.protobuf.archive.StreamEventIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamEventIndexRequest.mergeTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=2070,
)


_STREAMCOMPLETENESSINDEXREQUEST = _descriptor.Descriptor(
  name='StreamCompletenessIndexRequest',
  full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.StreamCompletenessIndexRequest.mergeTime', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2227,
)


_REBUILDCCSDSINDEXREQUEST = _descriptor.Descriptor(
  name='RebuildCcsdsIndexRequest',
  full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.RebuildCcsdsIndexRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2359,
)

_LISTCOMMANDHISTORYINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDHISTORYINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMPLETENESSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMPLETENESSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDEXRESPONSE.fields_by_name['group'].message_type = _INDEXGROUP
_INDEXGROUP.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_INDEXGROUP.fields_by_name['entry'].message_type = _INDEXENTRY
_STREAMPACKETINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPACKETINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENTINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENTINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMPLETENESSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMPLETENESSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REBUILDCCSDSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REBUILDCCSDSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListCommandHistoryIndexRequest'] = _LISTCOMMANDHISTORYINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListEventIndexRequest'] = _LISTEVENTINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListPacketIndexRequest'] = _LISTPACKETINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListParameterIndexRequest'] = _LISTPARAMETERINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListCompletenessIndexRequest'] = _LISTCOMPLETENESSINDEXREQUEST
DESCRIPTOR.message_types_by_name['IndexResponse'] = _INDEXRESPONSE
DESCRIPTOR.message_types_by_name['IndexGroup'] = _INDEXGROUP
DESCRIPTOR.message_types_by_name['IndexEntry'] = _INDEXENTRY
DESCRIPTOR.message_types_by_name['StreamPacketIndexRequest'] = _STREAMPACKETINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamParameterIndexRequest'] = _STREAMPARAMETERINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamCommandIndexRequest'] = _STREAMCOMMANDINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamEventIndexRequest'] = _STREAMEVENTINDEXREQUEST
DESCRIPTOR.message_types_by_name['StreamCompletenessIndexRequest'] = _STREAMCOMPLETENESSINDEXREQUEST
DESCRIPTOR.message_types_by_name['RebuildCcsdsIndexRequest'] = _REBUILDCCSDSINDEXREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCommandHistoryIndexRequest = _reflection.GeneratedProtocolMessageType('ListCommandHistoryIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDHISTORYINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListCommandHistoryIndexRequest)
  })
_sym_db.RegisterMessage(ListCommandHistoryIndexRequest)

ListEventIndexRequest = _reflection.GeneratedProtocolMessageType('ListEventIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventIndexRequest)
  })
_sym_db.RegisterMessage(ListEventIndexRequest)

ListPacketIndexRequest = _reflection.GeneratedProtocolMessageType('ListPacketIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketIndexRequest)
  })
_sym_db.RegisterMessage(ListPacketIndexRequest)

ListParameterIndexRequest = _reflection.GeneratedProtocolMessageType('ListParameterIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterIndexRequest)
  })
_sym_db.RegisterMessage(ListParameterIndexRequest)

ListCompletenessIndexRequest = _reflection.GeneratedProtocolMessageType('ListCompletenessIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPLETENESSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListCompletenessIndexRequest)
  })
_sym_db.RegisterMessage(ListCompletenessIndexRequest)

IndexResponse = _reflection.GeneratedProtocolMessageType('IndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _INDEXRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexResponse)
  })
_sym_db.RegisterMessage(IndexResponse)

IndexGroup = _reflection.GeneratedProtocolMessageType('IndexGroup', (_message.Message,), {
  'DESCRIPTOR' : _INDEXGROUP,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexGroup)
  })
_sym_db.RegisterMessage(IndexGroup)

IndexEntry = _reflection.GeneratedProtocolMessageType('IndexEntry', (_message.Message,), {
  'DESCRIPTOR' : _INDEXENTRY,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexEntry)
  })
_sym_db.RegisterMessage(IndexEntry)

StreamPacketIndexRequest = _reflection.GeneratedProtocolMessageType('StreamPacketIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPACKETINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamPacketIndexRequest)
  })
_sym_db.RegisterMessage(StreamPacketIndexRequest)

StreamParameterIndexRequest = _reflection.GeneratedProtocolMessageType('StreamParameterIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPARAMETERINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamParameterIndexRequest)
  })
_sym_db.RegisterMessage(StreamParameterIndexRequest)

StreamCommandIndexRequest = _reflection.GeneratedProtocolMessageType('StreamCommandIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMMANDINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamCommandIndexRequest)
  })
_sym_db.RegisterMessage(StreamCommandIndexRequest)

StreamEventIndexRequest = _reflection.GeneratedProtocolMessageType('StreamEventIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEVENTINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamEventIndexRequest)
  })
_sym_db.RegisterMessage(StreamEventIndexRequest)

StreamCompletenessIndexRequest = _reflection.GeneratedProtocolMessageType('StreamCompletenessIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMPLETENESSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamCompletenessIndexRequest)
  })
_sym_db.RegisterMessage(StreamCompletenessIndexRequest)

RebuildCcsdsIndexRequest = _reflection.GeneratedProtocolMessageType('RebuildCcsdsIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDCCSDSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.index_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.RebuildCcsdsIndexRequest)
  })
_sym_db.RegisterMessage(RebuildCcsdsIndexRequest)


DESCRIPTOR._options = None

_INDEXESAPI = _descriptor.ServiceDescriptor(
  name='IndexesApi',
  full_name='yamcs.protobuf.archive.IndexesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2362,
  serialized_end=4130,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListCommandHistoryIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListCommandHistoryIndex',
    index=0,
    containing_service=None,
    input_type=_LISTCOMMANDHISTORYINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003\'\n%/api/archive/{instance}/command-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListEventIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListEventIndex',
    index=1,
    containing_service=None,
    input_type=_LISTEVENTINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003%\n#/api/archive/{instance}/event-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListPacketIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListPacketIndex',
    index=2,
    containing_service=None,
    input_type=_LISTPACKETINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003&\n$/api/archive/{instance}/packet-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListParameterIndex',
    index=3,
    containing_service=None,
    input_type=_LISTPARAMETERINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003)\n\'/api/archive/{instance}/parameter-index',
  ),
  _descriptor.MethodDescriptor(
    name='ListCompletenessIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.ListCompletenessIndex',
    index=4,
    containing_service=None,
    input_type=_LISTCOMPLETENESSINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=b'\212\222\003,\n*/api/archive/{instance}/completeness-index',
  ),
  _descriptor.MethodDescriptor(
    name='StreamPacketIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamPacketIndex',
    index=5,
    containing_service=None,
    input_type=_STREAMPACKETINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\003.\032)/api/archive/{instance}:streamPacketIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamParameterIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamParameterIndex',
    index=6,
    containing_service=None,
    input_type=_STREAMPARAMETERINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\0031\032,/api/archive/{instance}:streamParameterIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCommandIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamCommandIndex',
    index=7,
    containing_service=None,
    input_type=_STREAMCOMMANDINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\003/\032*/api/archive/{instance}:streamCommandIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamEventIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamEventIndex',
    index=8,
    containing_service=None,
    input_type=_STREAMEVENTINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\003-\032(/api/archive/{instance}:streamEventIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCompletenessIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.StreamCompletenessIndex',
    index=9,
    containing_service=None,
    input_type=_STREAMCOMPLETENESSINDEXREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVERECORD,
    serialized_options=b'\212\222\0034\032//api/archive/{instance}:streamCompletenessIndex:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='RebuildCcsdsIndex',
    full_name='yamcs.protobuf.archive.IndexesApi.RebuildCcsdsIndex',
    index=10,
    containing_service=None,
    input_type=_REBUILDCCSDSINDEXREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003.\032)/api/archive/{instance}:rebuildCcsdsIndex:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_INDEXESAPI)

DESCRIPTOR.services_by_name['IndexesApi'] = _INDEXESAPI

# @@protoc_insertion_point(module_scope)
